############################################################ 
# AMPL Solvers based on NAG Library
############################################################ 
#
# This Makefile is intended for a build of NAG AMPL solvers.
# Building system:  
#       Windows 32-bit, cl (Microsoft Visual C++)
# NAG Library:      
#       C, Mark 8, CLDLL084ZL
#   
# Note that a suitable build of the ASL library is necessary.
# If you don't have it you can download its source codes from
#     http://netlib.sandia.gov/cgi-bin/netlib/netlibfiles.tar?filename=netlib/ampl/solvers
# as a tar archive. Or from
#    http://www.netlib.org/ampl/solvers/
#    http://netlib.sandia.gov/ampl/solvers/index.html
# as separate files. Please unzip it and follow README file
# for further instructions.
#
# Please edit the location of the libraries below and invoke
#       nmake -f Makefile.cldll084zl.cl all
# To test the solvers call
#       nmake -f Makefile.cldll084zl.cl test

#
# last update: 1/12/2010
# by Jan Fiala, jan@nag.co.uk
############################################################ 


######### NAG Library
# specify the path, name and optionally includes for the Library

NAG_LIBDIR = C:\math\NAG\CL08\cldll084zl
NAG_LIB = "$(NAG_LIBDIR)\lib\CLDLL084Z_nag.lib"
NAG_INC = /I"$(NAG_LIBDIR)\include"

######### AMPL Solver Library (ASL)
# specify the path, name and include directory with header files form AMPL

AMPL_LIBDIR = C:\honza\math\packages\ampl\amplsolver\sys.i686.msvc
AMPL_LIB = "$(AMPL_LIBDIR)\amplsolv.lib"
AMPL_INC = /I"$(AMPL_LIBDIR)"

######### Other Libraries
# here you can add additional libraries if necessary

LIBDIR = 
ADD_LIB =
ADD_INC =

######### Programs
# name of the compiler to be used

CC = cl

######### Definitions, flags
# additional definitions and compiler flags

DEFS =
FLAGS = /O2 /nologo
#FLAGS = /Od /Zi /Wall /nologo

############################################################ 

LIBS = $(AMPL_LIB) $(NAG_LIB) $(ADD_LIB)
INCS = $(AMPL_INC) $(NAG_INC) $(ADD_INC)

all : e04uc.exe e04ug.exe

e04uc.exe : 
	$(CC) $(FLAGS) $(INCS) $(DEFS) e04ucc_ampl.c $(LIBS) /Fe$@

e04ug.exe : 
	$(CC) $(FLAGS) $(INCS) $(DEFS) e04ugc_ampl.c $(LIBS) /Fe$@

clean:
	del *.o *.obj e04ug.exe e04uc.exe

test: test_e04uc test_e04ug

test_e04uc: e04uc.exe
	@echo "############################################################"
	@echo "# Mini test of e04uc.exe                                    "
	@echo "# Test1: Routine identification & licence check             "
	@echo "#   the result should start with:                           "
	@echo "#     E04UC, NAG C Library                            "
	@echo "#     Licence: valid                                        "
	@echo "# Test2: Simple test problem, Hock-Schittkowski #72         "
	@echo "#   an approximate results are:                             "
	@echo "#     x = [193.4, 179.5, 185.0, 168.7]                      "
	@echo "#     objective function = 727.679                          "
	@echo "############################################################"
	@echo "                                                            "
	@echo "#########################  TEST 1  #########################"
	e04uc.exe
	@echo "                                                            "
	@echo "#########################  TEST 2  #########################"
	e04uc.exe hs072.nl
	@echo "####################### END OF TEST ########################"
	@echo "                                                            "
	
test_e04ug: e04ug.exe
	@echo "############################################################"
	@echo "# Mini test of e04ug.exe                                    "
	@echo "# Test1: Routine identification & licence check             "
	@echo "#   the result should start with:                           "
	@echo "#     E04UG, NAG C Library                            "
	@echo "#     Licence: valid                                        "
	@echo "# Test2: Simple test problem, Hock-Schittkowski #72         "
	@echo "#   an approximate results are:                             "
	@echo "#     x = [193.4, 179.5, 185.0, 168.7]                      "
	@echo "#     objective function = 727.679                          "
	@echo "############################################################"
	@echo "                                                            "
	@echo "#########################  TEST 1  #########################"
	e04ug.exe
	@echo "                                                            "
	@echo "#########################  TEST 2  #########################"
	e04ug.exe hs072.nl print=3
	@echo "####################### END OF TEST ########################"
	@echo "                                                            "
	
help:
	@echo "The following targets can be invoked:                   "
	@echo "  e04uc.exe, e04ug.exe, all                             "
	@echo "                      ... build AMPL Solvers            "
	@echo "  test                ... on-screen test of the solvers "
	@echo "  clean               ... clean the executables         "

############################################################ 


